@@ -19,7 +19,18 @@ ProviderWindow::ProviderWindow(QWidget *parent, WrPlugin *plugin) :
     ui->tblProviders->setModel(model);
     ui->tblProviders->setProperty("FingerScrollable", true);
     ui->tblProviders->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
-    qDebug() << "Adding providers";
+    refreshProviders();
+    setAttribute(Qt::WA_Maemo5StackedWindow);
+}
+
+ProviderWindow::~ProviderWindow()
+{
+    delete ui;
+}
+
+void ProviderWindow::refreshProviders() {
+    qDebug() << "Refreshing providers";
+    model->clear();
     this->plugin = plugin;
     int row = 0;
     for(int i = 0; i<plugin->searchProviders().count(); i++) {
@@ -44,11 +55,6 @@ ProviderWindow::ProviderWindow(QWidget *parent, WrPlugin *plugin) :
     qDebug() << "Providers added";
 }
 
-ProviderWindow::~ProviderWindow()
-{
-    delete ui;
-}
-
 void ProviderWindow::changeEvent(QEvent *e)
 {
     QMainWindow::changeEvent(e);
@@ -91,7 +97,7 @@ void ProviderWindow::on_tblProviders_clicked(QModelIndex index)
         }
     }
     qDebug() << "done click";
-    this->close();
+//    this->close();
 }
 
 void ProviderWindow::on_actionAdd_Custom_Search_triggered()
